@@ -59,8 +59,6 @@ def dijkstra(matrix_name, start_n, end_n):
     ValueError: Начальный или конечный узел не присоединен к графу
     """
     node_adj = _set_graph(matrix_name)
-    if start_n is None:
-        return 'Точки еще не заданы'
     seen = set()
     inf = float('inf')
     weights = {i: [inf, 0] for i in node_adj.keys()}
